@@ -1,3 +1,6 @@
+
+op = par(no.readonly = TRUE)
+
 library(circlize)
 par(mar = c(1, 1, 1, 1), cex = 0.6)
 factors = letters[1:9]
@@ -33,4 +36,6 @@ circos.lines(sort(runif(10)*10), runif(10)*8, sector.index = "i", area = TRUE, b
 circos.text(5, 9, "type = 'l', area = TRUE\nbaseline = 'top'", sector.index = "i")
 
 circos.clear()
-par(cex = 1)
\ No newline at end of file
+par(cex = 1)
+
+par(op)
