@@ -1,3 +1,6 @@
+
+op = par(no.readonly = TRUE)
+
 library(circlize)
 
 factors = letters[1:8]
@@ -43,4 +46,6 @@ top.e2 = get.cell.meta.data("cell.top.radius", "e", 2)
 bottom.e3 = get.cell.meta.data("cell.bottom.radius", "e", 3)
 draw.sector(start.degree = start.e2, end.degree = end.f2, rou1 = top.e2, rou2 = bottom.e3, border = NA, col = "#FFFF0040")
 circos.info(plot = TRUE)
-circos.clear()
\ No newline at end of file
+circos.clear()
+
+par(op)
